@@ -1,5 +1,7 @@
 from .imports import *
 from .utils import *
 from .data.all import *
+from .metrics import *
+from .learner import *
 from .rocket_functions import *
 from .models.all import *
\ No newline at end of file
